<?php

namespace Drupal\Tests\field_group_ajaxified_multipage\Functional;

use Drupal\Tests\BrowserTestBase;
use Drupal\Tests\field_group\Functional\FieldGroupTestTrait;
use Drupal\Tests\field_group_ajaxified_multipage\Functional\FieldGroupAjaxifiedTrait;
use Drupal\Core\Url;

/**
 * Functional tests.
 *
 * @ingroup field_group_ajaxified_multipage
 *
 * @group field_group_ajaxified_multipage
 */
class FieldGroupAjaxifiedTest extends BrowserTestBase {

  use FieldGroupTestTrait;
  use FieldGroupAjaxifiedTrait;

  /**
   * Modules to enable.
   *
   * @var array
   */
  public static $modules = [
    'node',
    'field_test',
    'field_group',
    'field_group_ajaxified_multipage',
  ];

  /**
   * A user with permission to administer site configuration.
   *
   * @var \Drupal\user\UserInterface
   */
  protected $user;

  /**
   * Node type.
   *
   * @var string
   */
  protected $nodeType;

  /**
   * {@inheritdoc}
   */
  protected function setUp() {
    parent::setUp();
    $this->user = $this->drupalCreateUser([
      'administer content types',
      'bypass node access',
    ]);

    // Create content type, with underscores.
    $type_name = strtolower($this->randomMachineName(8)) . '_test';
    $type = $this->drupalCreateContentType([
      'name' => $type_name,
      'type' => $type_name,
    ]);
    $this->nodeType = $type->id();

    /** @var \Drupal\Core\Entity\Display\EntityViewDisplayInterface $display */
    $display = \Drupal::entityTypeManager()
      ->getStorage('entity_view_display')
      ->load('node.' . $type_name . '.default');

    $this->createField('field_test', $type_name, $display, ['required' => TRUE]);
    $this->createField('field_test_2', $type_name, $display);

    $data = [
      'format_type' => 'multipage',
      'label' => 'Multipage step 1',
      'children' => [
        0 => 'field_test',
      ],
      'format_settings' => [
        'label' => 'Multipage step 1',
      ],
    ];

    $step_1_fieldgroup = $this->createGroup('node', $this->nodeType, 'form', 'default', $data);

    $data = [
      'label' => 'Multipage step 2',
      'children' => [
        0 => 'field_test_2',
      ],
      'format_type' => 'multipage',
      'format_settings' => [
        'label' => 'Multipage step 2',
      ],
    ];

    $step_2_fieldgroup = $this->createGroup('node', $this->nodeType, 'form', 'default', $data);

    $data = [
      'label' => 'Multipage group',
      'children' => [
        0 => $step_1_fieldgroup->group_name,
        1 => $step_2_fieldgroup->group_name,
      ],
      'format_type' => 'multipage_group',
      'format_settings' => [
        'ajaxify' => '1',
        'nonjs_multistep' => '0',
        'classes' => ' group-steps field-group-multipage-group',
        'page_header' => '3',
        'page_counter' => '1',
      ],
    ];

    $this->createGroup('node', $this->nodeType, 'form', 'default', $data);

    // Save display + create node.
    $type->save();
    $display->save();
    $this->drupalLogin($this->user);
  }

  /**
   * Tests that the home page loads with a 200 response.
   */
  public function testFrontpage() {
    $this->drupalGet(Url::fromRoute('<front>'));
    $page = $this->getSession()->getPage();
    $this->assertResponse(200);
  }

}
