<?php

namespace Drupal\Tests\field_group_ajaxified_multipage\Functional;

use Drupal\field\Entity\FieldConfig;
use Drupal\field\Entity\FieldStorageConfig;
use Drupal\Core\Entity\Entity\EntityViewDisplay;

/**
 * Provides common functionality for the FieldGroupAjaxified test classes.
 */
trait FieldGroupAjaxifiedTrait {

  /**
   * Auxiliar method to create fields.
   *
   * @param string $field_name
   *   Field name.
   * @param string $node_type
   *   Node type.
   * @param \Drupal\Core\Entity\Entity\EntityViewDisplay $display
   *   Display.
   * @param array $options
   *   Options.
   */
  public function createField($field_name, $node_type, EntityViewDisplay $display, array $options = []) {
    $options += [
      'required' => FALSE,
    ];

    $field_storage = FieldStorageConfig::create([
      'field_name' => $field_name,
      'entity_type' => 'node',
      'type' => 'test_field',
    ]);
    $field_storage->save();

    $instance = FieldConfig::create([
      'field_storage' => $field_storage,
      'field_name' => $field_name,
      'bundle' => $node_type,
      'label' => $this->randomMachineName(),
      'required' => $options['required'],
    ]);

    $instance->save();

    // Set the field visible on the display object.
    $display_options = [
      'label' => 'above',
      'type' => 'field_test_default',
      'settings' => [
        'test_formatter_setting' => $this->randomMachineName(),
      ],
    ];
    $display->setComponent($field_name, $display_options);

    entity_get_form_display('node', $node_type, 'default')
      ->setComponent($field_name, [
        'type' => 'test_field_widget',
      ])
      ->save();

  }

}
